"use strict";
/**
 * Debug utility that wraps console methods and checks the global debug flag.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.debugError = exports.debugWarn = exports.debugInfo = exports.debugLog = void 0;
/**
 * Checks if debug mode is enabled
 * @returns Whether debug mode is enabled
 */
function isDebugEnabled() {
    return typeof globalThis.__SSE_DEBUG_ENABLED === 'boolean'
        ? globalThis.__SSE_DEBUG_ENABLED
        : false;
}
/* eslint-disable no-console */
/**
 * Logs a debug message to the console if debug mode is enabled
 * @param args The arguments to log
 */
const debugLog = (...args) => {
    if (isDebugEnabled())
        console.log('[SSE]', ...args);
};
exports.debugLog = debugLog;
/**
 * Logs an info message to the console if debug mode is enabled
 * @param args The arguments to log
 */
const debugInfo = (...args) => {
    if (isDebugEnabled())
        console.info('[SSE]', ...args);
};
exports.debugInfo = debugInfo;
/**
 * Logs a warning message to the console if debug mode is enabled
 * @param args The arguments to log
 */
const debugWarn = (...args) => {
    if (isDebugEnabled())
        console.warn('[SSE]', ...args);
};
exports.debugWarn = debugWarn;
/**
 * Logs an error message to the console if debug mode is enabled
 * @param args The arguments to log
 */
const debugError = (...args) => {
    if (isDebugEnabled())
        console.error('[SSE]', ...args);
};
exports.debugError = debugError;
/* eslint-enable no-console */
